@@ -5,5 +5,5 @@ import json
 
 def credit_left(request):
     credit = skebby_credit_left()
-    credit_dict = credit['body'] if not credit['error'] else {}
+    credit_dict = credit.skebby_response if not credit.skebby_error else {}
     return HttpResponse(json.dumps(credit_dict), mimetype="application/json")
